import { Link } from 'react-router-dom';
import { Mail, Phone, Instagram, Twitter, Facebook, ExternalLink } from 'lucide-react';
import { DesignStudioLogo } from './DesignStudioLogo';

export function Footer() {
  return (
    <footer className="bg-gray-900 text-gray-300">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-12">
        <div className="grid grid-cols-1 md:grid-cols-4 gap-8">
          {/* About Section */}
          <div className="col-span-2">
            <h2 className="text-xl font-bold text-white mb-4">About CultureScope</h2>
            <p className="text-gray-400 mb-4">
              CultureScope is your premier destination for arts and culture coverage. 
              Founded in 2024, we bring you the latest in film, theater, music, sports, 
              and cultural stories from around the globe.
            </p>
            <div className="flex space-x-4">
              <a href="https://twitter.com" className="hover:text-white transition-colors">
                <Twitter size={20} />
              </a>
              <a href="https://facebook.com" className="hover:text-white transition-colors">
                <Facebook size={20} />
              </a>
              <a href="https://instagram.com" className="hover:text-white transition-colors">
                <Instagram size={20} />
              </a>
            </div>
          </div>

          {/* Quick Links */}
          <div>
            <h3 className="text-lg font-semibold text-white mb-4">Quick Links</h3>
            <ul className="space-y-2">
              <li>
                <Link to="/?category=Film" className="hover:text-white transition-colors">
                  Film
                </Link>
              </li>
              <li>
                <Link to="/?category=Theater" className="hover:text-white transition-colors">
                  Theater
                </Link>
              </li>
              <li>
                <Link to="/?category=Music" className="hover:text-white transition-colors">
                  Music
                </Link>
              </li>
              <li>
                <Link to="/?category=Sports" className="hover:text-white transition-colors">
                  Sports
                </Link>
              </li>
              <li>
                <Link to="/?category=Art" className="hover:text-white transition-colors">
                  Art
                </Link>
              </li>
              <li>
                <Link to="/?category=Legends" className="hover:text-white transition-colors">
                  Legends
                </Link>
              </li>
              <li>
                <Link to="/?category=Anniversaries" className="hover:text-white transition-colors">
                  Anniversaries
                </Link>
              </li>
              <li>
                <Link to="/?category=Memory" className="hover:text-white transition-colors">
                  Memory
                </Link>
              </li>
            </ul>
          </div>

          {/* Contact Info */}
          <div>
            <h3 className="text-lg font-semibold text-white mb-4">Contact Us</h3>
            <ul className="space-y-4">
              <li className="flex items-center">
                <Mail size={18} className="mr-2" />
                <a href="mailto:contact@culturescope.com" className="hover:text-white transition-colors">
                  contact@culturescope.com
                </a>
              </li>
              <li className="flex items-center">
                <Phone size={18} className="mr-2" />
                <a href="tel:+1234567890" className="hover:text-white transition-colors">
                  (123) 456-7890
                </a>
              </li>
            </ul>

            <h3 className="text-lg font-semibold text-white mt-6 mb-4">Our Partners</h3>
            <ul className="space-y-2">
              <li className="flex items-center">
                <ExternalLink size={16} className="mr-2" />
                <a href="https://metropolitan.museum" className="hover:text-white transition-colors">
                  Metropolitan Museum
                </a>
              </li>
              <li className="flex items-center">
                <ExternalLink size={16} className="mr-2" />
                <a href="https://royalalberthall.com" className="hover:text-white transition-colors">
                  Royal Albert Hall
                </a>
              </li>
              <li className="flex items-center">
                <ExternalLink size={16} className="mr-2" />
                <a href="https://nationaltheatre.org.uk" className="hover:text-white transition-colors">
                  National Theatre
                </a>
              </li>
            </ul>
          </div>
        </div>

        <div className="border-t border-gray-800 mt-12 pt-8">
          <div className="flex flex-col md:flex-row justify-between items-center">
            <div className="flex items-center space-x-2">
              <p className="text-sm text-gray-400">
                © {new Date().getFullYear()} CultureScope. All rights reserved.
              </p>
              <span className="text-gray-600">•</span>
              <DesignStudioLogo />
            </div>
            <div className="flex space-x-6 mt-4 md:mt-0">
              <Link to="/privacy" className="text-sm text-gray-400 hover:text-white transition-colors">
                Privacy Policy
              </Link>
              <Link to="/terms" className="text-sm text-gray-400 hover:text-white transition-colors">
                Terms of Service
              </Link>
              <Link to="/sitemap" className="text-sm text-gray-400 hover:text-white transition-colors">
                Sitemap
              </Link>
            </div>
          </div>
        </div>
      </div>
    </footer>
  );
}